.. _about:


About
=====
django-handyhelpers is a collection of handy utilities to support Django operations. Features include:

    * management commands to generate admin pages
    * management commands to generate, views, serializers, and urls for Django Rest Framework (DRF)
    * generic base model with extensive model manager
    * generic list views and FilterByQueryParamsMixin
    * xls and csv export views
    * InvalidLookupMixin for DRF viewsets
    * a collection of generic bootstrap-based html templates

See details on django-handyhelpers features on the :ref:`Features <features>` page


Requirements & Dependencies
---------------------------

django-handyhelpers is built on Python 3.6.x and Django 2.2.x. For a full list of packages and requirements, please
see the requirements.txt file: https://github.com/davidslusser/django-handyhelpers/blob/master/requirements.txt
